#[repr(C, u8)]pub enum AssignmentTarget<'a> {
AssignmentTargetIdentifier(Box<'a, IdentifierReference<'a>>),
TSAsExpression(Box<'a, TSAsExpression<'a>>),
TSSatisfiesExpression(Box<'a, TSSatisfiesExpression<'a>>),
TSNonNullExpression(Box<'a, TSNonNullExpression<'a>>),
TSTypeAssertion(Box<'a, TSTypeAssertion<'a>>),
ComputedMemberExpression(Box<'a, ComputedMemberExpression<'a>>),
StaticMemberExpression(Box<'a, StaticMemberExpression<'a>>),
PrivateFieldExpression(Box<'a, PrivateFieldExpression<'a>>),
ArrayAssignmentTarget(Box<'a, ArrayAssignmentTarget<'a>>),
ObjectAssignmentTarget(Box<'a, ObjectAssignmentTarget<'a>>),
}Expand description
Destructuring Assignment
Inherits variants from SimpleAssignmentTarget and AssignmentTargetPattern.
See ast module docs for explanation of inheritance.
Variants
AssignmentTargetIdentifier(Box<'a, IdentifierReference<'a>>)
Inherited from SimpleAssignmentTarget
TSAsExpression(Box<'a, TSAsExpression<'a>>)
Inherited from SimpleAssignmentTarget
TSSatisfiesExpression(Box<'a, TSSatisfiesExpression<'a>>)
Inherited from SimpleAssignmentTarget
TSNonNullExpression(Box<'a, TSNonNullExpression<'a>>)
Inherited from SimpleAssignmentTarget
TSTypeAssertion(Box<'a, TSTypeAssertion<'a>>)
Inherited from SimpleAssignmentTarget
ComputedMemberExpression(Box<'a, ComputedMemberExpression<'a>>)
Inherited from SimpleAssignmentTarget
StaticMemberExpression(Box<'a, StaticMemberExpression<'a>>)
Inherited from SimpleAssignmentTarget
PrivateFieldExpression(Box<'a, PrivateFieldExpression<'a>>)
Inherited from SimpleAssignmentTarget
ArrayAssignmentTarget(Box<'a, ArrayAssignmentTarget<'a>>)
Inherited from AssignmentTargetPattern
ObjectAssignmentTarget(Box<'a, ObjectAssignmentTarget<'a>>)
Inherited from AssignmentTargetPattern
Implementations
Sourceimpl<'a> AssignmentTarget<'a>
impl<'a> AssignmentTarget<'a>
Sourcepub fn get_identifier_name(&self) -> Option<&'a str>
pub fn get_identifier_name(&self) -> Option<&'a str>
Returns the identifier name of this assignment target when it is simple like a = b.
Example
- returns
awhen called on the left-hand side ofa = b - returns
bwhen called on the left-hand side ofa.b = b - returns
Nonewhen called on the left-hand side ofa[b] = b
Sourcepub fn get_expression(&self) -> Option<&Expression<'a>>
pub fn get_expression(&self) -> Option<&Expression<'a>>
Returns the expression inside of this assignment target, if applicable, and returns a reference to it.
For getting a mutable reference of the expression inside, use AssignmentTarget::get_expression_mut.
Example
- returns
awhen called ona!ina! = b - returns
Nonewhen called onaina = bbecause there is no inner expression to get
Sourcepub fn get_expression_mut(&mut self) -> Option<&mut Expression<'a>>
pub fn get_expression_mut(&mut self) -> Option<&mut Expression<'a>>
Returns the expression inside of this assignment target, if applicable, and returns a mutable reference to it.
For getting an immutable reference of the expression inside, use AssignmentTarget::get_expression.
Example
- returns
awhen called ona!ina! = b - returns
Nonewhen called onaina = bbecause there is no inner expression to get
Sourceimpl<'a> AssignmentTarget<'a>
impl<'a> AssignmentTarget<'a>
Sourcepub fn new_assignment_target_identifier<B: GetAstBuilder<'a>, S1>(
span: Span,
name: S1,
builder: &B,
) -> Self
pub fn new_assignment_target_identifier<B: GetAstBuilder<'a>, S1>( span: Span, name: S1, builder: &B, ) -> Self
Build an AssignmentTarget::AssignmentTargetIdentifier.
This node contains an IdentifierReference that will be stored in the memory arena.
Parameters
span: TheSpancovering this nodename: The name of the identifier being referenced.
Sourcepub fn new_assignment_target_identifier_with_reference_id<B: GetAstBuilder<'a>, S1>(
span: Span,
name: S1,
reference_id: ReferenceId,
builder: &B,
) -> Self
pub fn new_assignment_target_identifier_with_reference_id<B: GetAstBuilder<'a>, S1>( span: Span, name: S1, reference_id: ReferenceId, builder: &B, ) -> Self
Build an AssignmentTarget::AssignmentTargetIdentifier with reference_id.
This node contains an IdentifierReference that will be stored in the memory arena.
Parameters
span: TheSpancovering this nodename: The name of the identifier being referenced.reference_id: Reference ID
Sourcepub fn new_ts_as_expression<B: GetAstBuilder<'a>>(
span: Span,
expression: Expression<'a>,
type_annotation: TSType<'a>,
builder: &B,
) -> Self
pub fn new_ts_as_expression<B: GetAstBuilder<'a>>( span: Span, expression: Expression<'a>, type_annotation: TSType<'a>, builder: &B, ) -> Self
Build an AssignmentTarget::TSAsExpression.
This node contains a TSAsExpression that will be stored in the memory arena.
Parameters
span: TheSpancovering this nodeexpressiontype_annotation
Sourcepub fn new_ts_satisfies_expression<B: GetAstBuilder<'a>>(
span: Span,
expression: Expression<'a>,
type_annotation: TSType<'a>,
builder: &B,
) -> Self
pub fn new_ts_satisfies_expression<B: GetAstBuilder<'a>>( span: Span, expression: Expression<'a>, type_annotation: TSType<'a>, builder: &B, ) -> Self
Build an AssignmentTarget::TSSatisfiesExpression.
This node contains a TSSatisfiesExpression that will be stored in the memory arena.
Parameters
span: TheSpancovering this nodeexpression: The value expression being constrained.type_annotation: The typeexpressionmust satisfy.
Sourcepub fn new_ts_non_null_expression<B: GetAstBuilder<'a>>(
span: Span,
expression: Expression<'a>,
builder: &B,
) -> Self
pub fn new_ts_non_null_expression<B: GetAstBuilder<'a>>( span: Span, expression: Expression<'a>, builder: &B, ) -> Self
Build an AssignmentTarget::TSNonNullExpression.
This node contains a TSNonNullExpression that will be stored in the memory arena.
Parameters
span: TheSpancovering this nodeexpression
Sourcepub fn new_ts_type_assertion<B: GetAstBuilder<'a>>(
span: Span,
type_annotation: TSType<'a>,
expression: Expression<'a>,
builder: &B,
) -> Self
pub fn new_ts_type_assertion<B: GetAstBuilder<'a>>( span: Span, type_annotation: TSType<'a>, expression: Expression<'a>, builder: &B, ) -> Self
Build an AssignmentTarget::TSTypeAssertion.
This node contains a TSTypeAssertion that will be stored in the memory arena.
Parameters
span: TheSpancovering this nodetype_annotationexpression
Sourcepub fn new_computed_member_expression<B: GetAstBuilder<'a>>(
span: Span,
object: Expression<'a>,
expression: Expression<'a>,
optional: bool,
builder: &B,
) -> Self
pub fn new_computed_member_expression<B: GetAstBuilder<'a>>( span: Span, object: Expression<'a>, expression: Expression<'a>, optional: bool, builder: &B, ) -> Self
Build an AssignmentTarget::ComputedMemberExpression.
This node contains a ComputedMemberExpression that will be stored in the memory arena.
Parameters
span: TheSpancovering this nodeobjectexpressionoptional
Sourcepub fn new_static_member_expression<B: GetAstBuilder<'a>>(
span: Span,
object: Expression<'a>,
property: IdentifierName<'a>,
optional: bool,
builder: &B,
) -> Self
pub fn new_static_member_expression<B: GetAstBuilder<'a>>( span: Span, object: Expression<'a>, property: IdentifierName<'a>, optional: bool, builder: &B, ) -> Self
Build an AssignmentTarget::StaticMemberExpression.
This node contains a StaticMemberExpression that will be stored in the memory arena.
Parameters
span: TheSpancovering this nodeobjectpropertyoptional
Sourcepub fn new_private_field_expression<B: GetAstBuilder<'a>>(
span: Span,
object: Expression<'a>,
field: PrivateIdentifier<'a>,
optional: bool,
builder: &B,
) -> Self
pub fn new_private_field_expression<B: GetAstBuilder<'a>>( span: Span, object: Expression<'a>, field: PrivateIdentifier<'a>, optional: bool, builder: &B, ) -> Self
Build an AssignmentTarget::PrivateFieldExpression.
This node contains a PrivateFieldExpression that will be stored in the memory arena.
Parameters
span: TheSpancovering this nodeobjectfieldoptional
Sourcepub fn new_array_assignment_target<B: GetAstBuilder<'a>, T1>(
span: Span,
elements: ArenaVec<'a, Option<AssignmentTargetMaybeDefault<'a>>>,
rest: T1,
builder: &B,
) -> Self
pub fn new_array_assignment_target<B: GetAstBuilder<'a>, T1>( span: Span, elements: ArenaVec<'a, Option<AssignmentTargetMaybeDefault<'a>>>, rest: T1, builder: &B, ) -> Self
Build an AssignmentTarget::ArrayAssignmentTarget.
This node contains an ArrayAssignmentTarget that will be stored in the memory arena.
Parameters
span: TheSpancovering this nodeelementsrest
Sourcepub fn new_object_assignment_target<B: GetAstBuilder<'a>, T1>(
span: Span,
properties: ArenaVec<'a, AssignmentTargetProperty<'a>>,
rest: T1,
builder: &B,
) -> Self
pub fn new_object_assignment_target<B: GetAstBuilder<'a>, T1>( span: Span, properties: ArenaVec<'a, AssignmentTargetProperty<'a>>, rest: T1, builder: &B, ) -> Self
Build an AssignmentTarget::ObjectAssignmentTarget.
This node contains an ObjectAssignmentTarget that will be stored in the memory arena.
Parameters
span: TheSpancovering this nodepropertiesrest
Sourceimpl AssignmentTarget<'_>
impl AssignmentTarget<'_>
Sourcepub fn node_id(&self) -> NodeId
pub fn node_id(&self) -> NodeId
Get NodeId of AssignmentTarget.
Sourceimpl<'a> AssignmentTarget<'a>
impl<'a> AssignmentTarget<'a>
Sourcepub fn is_simple_assignment_target(&self) -> bool
pub fn is_simple_assignment_target(&self) -> bool
Return if an AssignmentTarget is a SimpleAssignmentTarget.
Sourcepub fn into_simple_assignment_target(self) -> SimpleAssignmentTarget<'a>
pub fn into_simple_assignment_target(self) -> SimpleAssignmentTarget<'a>
Sourcepub fn as_simple_assignment_target(&self) -> Option<&SimpleAssignmentTarget<'a>>
pub fn as_simple_assignment_target(&self) -> Option<&SimpleAssignmentTarget<'a>>
Convert an &AssignmentTarget to a &SimpleAssignmentTarget.
Sourcepub fn as_simple_assignment_target_mut(
&mut self,
) -> Option<&mut SimpleAssignmentTarget<'a>>
pub fn as_simple_assignment_target_mut( &mut self, ) -> Option<&mut SimpleAssignmentTarget<'a>>
Convert an &mut AssignmentTarget to a &mut SimpleAssignmentTarget.
Sourcepub fn to_simple_assignment_target(&self) -> &SimpleAssignmentTarget<'a>
pub fn to_simple_assignment_target(&self) -> &SimpleAssignmentTarget<'a>
Sourcepub fn to_simple_assignment_target_mut(
&mut self,
) -> &mut SimpleAssignmentTarget<'a>
pub fn to_simple_assignment_target_mut( &mut self, ) -> &mut SimpleAssignmentTarget<'a>
Convert an &mut AssignmentTarget to a &mut SimpleAssignmentTarget.
Panics
Panics if not convertible.
Sourceimpl<'a> AssignmentTarget<'a>
impl<'a> AssignmentTarget<'a>
Sourcepub fn is_member_expression(&self) -> bool
pub fn is_member_expression(&self) -> bool
Return if an AssignmentTarget is a MemberExpression.
Sourcepub fn into_member_expression(self) -> MemberExpression<'a>
pub fn into_member_expression(self) -> MemberExpression<'a>
Sourcepub fn as_member_expression(&self) -> Option<&MemberExpression<'a>>
pub fn as_member_expression(&self) -> Option<&MemberExpression<'a>>
Convert an &AssignmentTarget to a &MemberExpression.
Sourcepub fn as_member_expression_mut(&mut self) -> Option<&mut MemberExpression<'a>>
pub fn as_member_expression_mut(&mut self) -> Option<&mut MemberExpression<'a>>
Convert an &mut AssignmentTarget to a &mut MemberExpression.
Sourcepub fn to_member_expression(&self) -> &MemberExpression<'a>
pub fn to_member_expression(&self) -> &MemberExpression<'a>
Sourcepub fn to_member_expression_mut(&mut self) -> &mut MemberExpression<'a>
pub fn to_member_expression_mut(&mut self) -> &mut MemberExpression<'a>
Sourceimpl<'a> AssignmentTarget<'a>
impl<'a> AssignmentTarget<'a>
Sourcepub fn is_assignment_target_pattern(&self) -> bool
pub fn is_assignment_target_pattern(&self) -> bool
Return if an AssignmentTarget is an AssignmentTargetPattern.
Sourcepub fn into_assignment_target_pattern(self) -> AssignmentTargetPattern<'a>
pub fn into_assignment_target_pattern(self) -> AssignmentTargetPattern<'a>
Sourcepub fn as_assignment_target_pattern(
&self,
) -> Option<&AssignmentTargetPattern<'a>>
pub fn as_assignment_target_pattern( &self, ) -> Option<&AssignmentTargetPattern<'a>>
Convert an &AssignmentTarget to an &AssignmentTargetPattern.
Sourcepub fn as_assignment_target_pattern_mut(
&mut self,
) -> Option<&mut AssignmentTargetPattern<'a>>
pub fn as_assignment_target_pattern_mut( &mut self, ) -> Option<&mut AssignmentTargetPattern<'a>>
Convert an &mut AssignmentTarget to an &mut AssignmentTargetPattern.
Sourcepub fn to_assignment_target_pattern(&self) -> &AssignmentTargetPattern<'a>
pub fn to_assignment_target_pattern(&self) -> &AssignmentTargetPattern<'a>
Sourcepub fn to_assignment_target_pattern_mut(
&mut self,
) -> &mut AssignmentTargetPattern<'a>
pub fn to_assignment_target_pattern_mut( &mut self, ) -> &mut AssignmentTargetPattern<'a>
Convert an &mut AssignmentTarget to an &mut AssignmentTargetPattern.
Panics
Panics if not convertible.
Sourceimpl<'a> AssignmentTarget<'a>
impl<'a> AssignmentTarget<'a>
Sourcepub fn as_assignment_target_maybe_default(
&self,
) -> &AssignmentTargetMaybeDefault<'a>
pub fn as_assignment_target_maybe_default( &self, ) -> &AssignmentTargetMaybeDefault<'a>
Convert an &AssignmentTarget to an &AssignmentTargetMaybeDefault.
Sourceimpl<'a> AssignmentTarget<'a>
impl<'a> AssignmentTarget<'a>
Sourcepub fn as_for_statement_left(&self) -> &ForStatementLeft<'a>
pub fn as_for_statement_left(&self) -> &ForStatementLeft<'a>
Convert an &AssignmentTarget to a &ForStatementLeft.