AssignmentTarget

Enum AssignmentTarget 

#[repr(C, u8)]
pub enum AssignmentTarget<'a> { AssignmentTargetIdentifier(Box<'a, IdentifierReference<'a>>), TSAsExpression(Box<'a, TSAsExpression<'a>>), TSSatisfiesExpression(Box<'a, TSSatisfiesExpression<'a>>), TSNonNullExpression(Box<'a, TSNonNullExpression<'a>>), TSTypeAssertion(Box<'a, TSTypeAssertion<'a>>), ComputedMemberExpression(Box<'a, ComputedMemberExpression<'a>>), StaticMemberExpression(Box<'a, StaticMemberExpression<'a>>), PrivateFieldExpression(Box<'a, PrivateFieldExpression<'a>>), ArrayAssignmentTarget(Box<'a, ArrayAssignmentTarget<'a>>), ObjectAssignmentTarget(Box<'a, ObjectAssignmentTarget<'a>>), }
Destructuring Assignment

Inherits variants from SimpleAssignmentTarget and AssignmentTargetPattern. See ast module docs for explanation of inheritance.

Variants



AssignmentTargetIdentifier(Box<'a, IdentifierReference<'a>>)

Inherited from SimpleAssignmentTarget



TSAsExpression(Box<'a, TSAsExpression<'a>>)

Inherited from SimpleAssignmentTarget



TSSatisfiesExpression(Box<'a, TSSatisfiesExpression<'a>>)

Inherited from SimpleAssignmentTarget



TSNonNullExpression(Box<'a, TSNonNullExpression<'a>>)

Inherited from SimpleAssignmentTarget



TSTypeAssertion(Box<'a, TSTypeAssertion<'a>>)

Inherited from SimpleAssignmentTarget



ComputedMemberExpression(Box<'a, ComputedMemberExpression<'a>>)

Inherited from SimpleAssignmentTarget



StaticMemberExpression(Box<'a, StaticMemberExpression<'a>>)

Inherited from SimpleAssignmentTarget



PrivateFieldExpression(Box<'a, PrivateFieldExpression<'a>>)

Inherited from SimpleAssignmentTarget



ArrayAssignmentTarget(Box<'a, ArrayAssignmentTarget<'a>>)

Inherited from AssignmentTargetPattern



ObjectAssignmentTarget(Box<'a, ObjectAssignmentTarget<'a>>)

Inherited from AssignmentTargetPattern

Implementations

Source

impl<'a> AssignmentTarget<'a>

pub fn get_identifier_name(&self) -> Option<&'a str>

Returns the identifier name of this assignment target when it is simple like a = b.

Example
  • returns a when called on the left-hand side of a = b
  • returns b when called on the left-hand side of a.b = b
  • returns None when called on the left-hand side of a[b] = b
pub fn get_expression(&self) -> Option<&Expression<'a>>

Returns the expression inside of this assignment target, if applicable, and returns a reference to it.

For getting a mutable reference of the expression inside, use AssignmentTarget::get_expression_mut.

Example
  • returns a when called on a! in a! = b
  • returns None when called on a in a = b because there is no inner expression to get
pub fn get_expression_mut(&mut self) -> Option<&mut Expression<'a>>

Returns the expression inside of this assignment target, if applicable, and returns a mutable reference to it.

For getting an immutable reference of the expression inside, use AssignmentTarget::get_expression.

Example
  • returns a when called on a! in a! = b
  • returns None when called on a in a = b because there is no inner expression to get
Source

impl<'a> AssignmentTarget<'a>

pub fn new_assignment_target_identifier<B: GetAstBuilder<'a>, S1>( span: Span, name: S1, builder: &B, ) -> Self
where S1: Into<Ident<'a>>,

Build an AssignmentTarget::AssignmentTargetIdentifier.

This node contains an IdentifierReference that will be stored in the memory arena.

Parameters
  • span: The Span covering this node
  • name: The name of the identifier being referenced.
pub fn new_assignment_target_identifier_with_reference_id<B: GetAstBuilder<'a>, S1>( span: Span, name: S1, reference_id: ReferenceId, builder: &B, ) -> Self
where S1: Into<Ident<'a>>,

Build an AssignmentTarget::AssignmentTargetIdentifier with reference_id.

This node contains an IdentifierReference that will be stored in the memory arena.

Parameters
  • span: The Span covering this node
  • name: The name of the identifier being referenced.
  • reference_id: Reference ID
pub fn new_ts_as_expression<B: GetAstBuilder<'a>>( span: Span, expression: Expression<'a>, type_annotation: TSType<'a>, builder: &B, ) -> Self

Build an AssignmentTarget::TSAsExpression.

This node contains a TSAsExpression that will be stored in the memory arena.

Parameters
  • span: The Span covering this node
  • expression
  • type_annotation
pub fn new_ts_satisfies_expression<B: GetAstBuilder<'a>>( span: Span, expression: Expression<'a>, type_annotation: TSType<'a>, builder: &B, ) -> Self

Build an AssignmentTarget::TSSatisfiesExpression.

This node contains a TSSatisfiesExpression that will be stored in the memory arena.

Parameters
  • span: The Span covering this node
  • expression: The value expression being constrained.
  • type_annotation: The type expression must satisfy.
pub fn new_ts_non_null_expression<B: GetAstBuilder<'a>>( span: Span, expression: Expression<'a>, builder: &B, ) -> Self

Build an AssignmentTarget::TSNonNullExpression.

This node contains a TSNonNullExpression that will be stored in the memory arena.

Parameters
  • span: The Span covering this node
  • expression
pub fn new_ts_type_assertion<B: GetAstBuilder<'a>>( span: Span, type_annotation: TSType<'a>, expression: Expression<'a>, builder: &B, ) -> Self

Build an AssignmentTarget::TSTypeAssertion.

This node contains a TSTypeAssertion that will be stored in the memory arena.

Parameters
  • span: The Span covering this node
  • type_annotation
  • expression
pub fn new_computed_member_expression<B: GetAstBuilder<'a>>( span: Span, object: Expression<'a>, expression: Expression<'a>, optional: bool, builder: &B, ) -> Self

Build an AssignmentTarget::ComputedMemberExpression.

This node contains a ComputedMemberExpression that will be stored in the memory arena.

Parameters
  • span: The Span covering this node
  • object
  • expression
  • optional
pub fn new_static_member_expression<B: GetAstBuilder<'a>>( span: Span, object: Expression<'a>, property: IdentifierName<'a>, optional: bool, builder: &B, ) -> Self

Build an AssignmentTarget::StaticMemberExpression.

This node contains a StaticMemberExpression that will be stored in the memory arena.

Parameters
  • span: The Span covering this node
  • object
  • property
  • optional
pub fn new_private_field_expression<B: GetAstBuilder<'a>>( span: Span, object: Expression<'a>, field: PrivateIdentifier<'a>, optional: bool, builder: &B, ) -> Self

Build an AssignmentTarget::PrivateFieldExpression.

This node contains a PrivateFieldExpression that will be stored in the memory arena.

Parameters
  • span: The Span covering this node
  • object
  • field
  • optional
pub fn new_array_assignment_target<B: GetAstBuilder<'a>, T1>( span: Span, elements: ArenaVec<'a, Option<AssignmentTargetMaybeDefault<'a>>>, rest: T1, builder: &B, ) -> Self
where T1: IntoIn<'a, Option<ArenaBox<'a, AssignmentTargetRest<'a>>>>,

Build an AssignmentTarget::ArrayAssignmentTarget.

This node contains an ArrayAssignmentTarget that will be stored in the memory arena.

Parameters
  • span: The Span covering this node
  • elements
  • rest
pub fn new_object_assignment_target<B: GetAstBuilder<'a>, T1>( span: Span, properties: ArenaVec<'a, AssignmentTargetProperty<'a>>, rest: T1, builder: &B, ) -> Self
where T1: IntoIn<'a, Option<ArenaBox<'a, AssignmentTargetRest<'a>>>>,

Build an AssignmentTarget::ObjectAssignmentTarget.

This node contains an ObjectAssignmentTarget that will be stored in the memory arena.

Parameters
  • span: The Span covering this node
  • properties
  • rest
Source

impl AssignmentTarget<'_>

pub fn node_id(&self) -> NodeId

Source

impl<'a> AssignmentTarget<'a>

Source

impl<'a> AssignmentTarget<'a>

pub fn is_member_expression(&self) -> bool

pub fn into_member_expression(self) -> MemberExpression<'a>

Convert an AssignmentTarget to a MemberExpression.

Panics

Panics if not convertible.

pub fn as_member_expression(&self) -> Option<&MemberExpression<'a>>

pub fn as_member_expression_mut(&mut self) -> Option<&mut MemberExpression<'a>>

pub fn to_member_expression(&self) -> &MemberExpression<'a>

Convert an &AssignmentTarget to a &MemberExpression.

Panics

Panics if not convertible.

pub fn to_member_expression_mut(&mut self) -> &mut MemberExpression<'a>

Convert an &mut AssignmentTarget to a &mut MemberExpression.

Panics

Panics if not convertible.

Source

impl<'a> AssignmentTarget<'a>

Source

impl<'a> AssignmentTarget<'a>

Source

impl<'a> AssignmentTarget<'a>